@@ -9,10 +9,7 @@
 
 G_BEGIN_DECLS
 
-/* This is deprecated, don't use */
-#define PYGIL_API_IS_BUGGY FALSE
-
-  /* PyGClosure is a _private_ structure */
+/* PyGClosure is a _private_ structure */
 typedef void (* PyClosureExceptionHandler) (GValue *ret, guint n_param_values, const GValue *params);
 typedef struct _PyGClosure PyGClosure;
 typedef struct _PyGObjectData PyGObjectData;
@@ -26,7 +23,8 @@ struct _PyGClosure {
 };
 
 typedef enum {
-    PYGOBJECT_USING_TOGGLE_REF = 1 << 0
+    PYGOBJECT_USING_TOGGLE_REF = 1 << 0,
+    PYGOBJECT_IS_FLOATING_REF = 1 << 1
 } PyGObjectFlags;
 
   /* closures is just an alias for what is found in the
@@ -180,12 +178,6 @@ struct _PyGObject_Functions {
     void      (*register_class_init) (GType gtype, PyGClassInitFunc class_init);
     void      (*register_interface_info) (GType gtype, const GInterfaceInfo *info);
     void      (*closure_set_exception_handler) (GClosure *closure, PyClosureExceptionHandler handler);
-    int       (*pygobject_constructv) (PyGObject  *self,
-                                       guint       n_parameters,
-                                       GParameter *parameters);
-    int       (*pygobject_construct) (PyGObject  *self,
-                                      const char *first_property_name,
-                                      ...);
 
     void      (*add_warning_redirection) (const char *domain,
                                           PyObject   *warning);
@@ -219,8 +211,6 @@ struct _PyGObject_Functions *_PyGObject_API;
 #define pyg_type_wrapper_new        (_PyGObject_API->type_wrapper_new)
 #define pyg_enum_get_value          (_PyGObject_API->enum_get_value)
 #define pyg_flags_get_value         (_PyGObject_API->flags_get_value)
-/* This is deprecated, call pyg_register_gtype_custom directly instead */
-#define pyg_register_boxed_custom   pyg_register_gtype_custom
 #define pyg_register_gtype_custom   (_PyGObject_API->register_gtype_custom)
 #define pyg_value_from_pyobject     (_PyGObject_API->value_from_pyobject)
 #define pyg_value_as_pyobject       (_PyGObject_API->value_as_pyobject)
@@ -254,8 +244,6 @@ struct _PyGObject_Functions *_PyGObject_API;
 #define pyg_gil_state_release       (_PyGObject_API->gil_state_release)
 #define pyg_register_class_init     (_PyGObject_API->register_class_init)
 #define pyg_register_interface_info (_PyGObject_API->register_interface_info)
-#define pygobject_construct         (_PyGObject_API->pygobject_construct)
-#define pygobject_constructv        (_PyGObject_API->pygobject_constructv)
 #define pyg_add_warning_redirection   (_PyGObject_API->add_warning_redirection)
 #define pyg_disable_warning_redirections (_PyGObject_API->disable_warning_redirections)
 #define pyg_type_register_custom_callback (_PyGObject_API->type_register_custom)
@@ -369,8 +357,6 @@ pygobject_init(int req_major, int req_minor, int req_micro)
         PyObject *version;
 
         version = PyObject_GetAttrString(gobject, "pygobject_version");
-        if (!version)
-            version = PyObject_GetAttrString(gobject, "pygtk_version");
         if (!version) {
             PyErr_SetString(PyExc_ImportError,
                             "could not import gobject (version too old)");
@@ -400,18 +386,6 @@ pygobject_init(int req_major, int req_minor, int req_micro)
     return gobject;
 }
 
-/* deprecated macro, use pygobject_init() instead. */
-#define init_pygobject() G_STMT_START {         \
-    if (!pygobject_init(-1, -1, -1))            \
-        return;                                 \
-} G_STMT_END
-
-/* deprecated macro, use pygobject_init() instead. */
-#define init_pygobject_check(req_major, req_minor, req_micro) G_STMT_START {    \
-    if (!pygobject_init(req_major, req_minor, req_micro))                       \
-        return;                                                                 \
-} G_STMT_END
-
 /**
  * PYLIST_FROMGLIBLIST:
  * @type: the type of the GLib list e.g. #GList or #GSList
